"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var _a, _b;
var react_1 = __importDefault(require("react"));
var rich_text_types_1 = require("@contentful/rich-text-types");
var NODE_KEY_I = 0;
var defaultNodeRenderers = (_a = {},
    _a[rich_text_types_1.BLOCKS.PARAGRAPH] = function (node, next) { return react_1.default.createElement("p", null, next(node.content)); },
    _a[rich_text_types_1.BLOCKS.HEADING_1] = function (node, next) { return react_1.default.createElement("h1", null, next(node.content)); },
    _a[rich_text_types_1.BLOCKS.HEADING_2] = function (node, next) { return react_1.default.createElement("h2", null, next(node.content)); },
    _a[rich_text_types_1.BLOCKS.HEADING_3] = function (node, next) { return react_1.default.createElement("h3", null, next(node.content)); },
    _a[rich_text_types_1.BLOCKS.HEADING_4] = function (node, next) { return react_1.default.createElement("h4", null, next(node.content)); },
    _a[rich_text_types_1.BLOCKS.HEADING_5] = function (node, next) { return react_1.default.createElement("h5", null, next(node.content)); },
    _a[rich_text_types_1.BLOCKS.HEADING_6] = function (node, next) { return react_1.default.createElement("h6", null, next(node.content)); },
    _a[rich_text_types_1.BLOCKS.EMBEDDED_ENTRY] = function (node, next) { return react_1.default.createElement("div", null, next(node.content)); },
    _a[rich_text_types_1.BLOCKS.UL_LIST] = function (node, next) { return react_1.default.createElement("ul", null, next(node.content)); },
    _a[rich_text_types_1.BLOCKS.OL_LIST] = function (node, next) { return react_1.default.createElement("ol", null, next(node.content)); },
    _a[rich_text_types_1.BLOCKS.LIST_ITEM] = function (node, next) { return react_1.default.createElement("li", null, next(node.content)); },
    _a[rich_text_types_1.BLOCKS.QUOTE] = function (node, next) { return react_1.default.createElement("blockquote", null, next(node.content)); },
    _a[rich_text_types_1.BLOCKS.HR] = function () { return react_1.default.createElement("hr", null); },
    _a[rich_text_types_1.INLINES.ASSET_HYPERLINK] = function (node) { return defaultInline(rich_text_types_1.INLINES.ASSET_HYPERLINK, node); },
    _a[rich_text_types_1.INLINES.ENTRY_HYPERLINK] = function (node) { return defaultInline(rich_text_types_1.INLINES.ENTRY_HYPERLINK, node); },
    _a[rich_text_types_1.INLINES.EMBEDDED_ENTRY] = function (node) { return defaultInline(rich_text_types_1.INLINES.EMBEDDED_ENTRY, node); },
    _a[rich_text_types_1.INLINES.HYPERLINK] = function (node, next) { return react_1.default.createElement("a", { href: node.data.uri }, next(node.content)); },
    _a);
var defaultMarkRenderers = (_b = {},
    _b[rich_text_types_1.MARKS.BOLD] = function (text) { return react_1.default.createElement("b", null, text); },
    _b[rich_text_types_1.MARKS.ITALIC] = function (text) { return react_1.default.createElement("i", null, text); },
    _b[rich_text_types_1.MARKS.UNDERLINE] = function (text) { return react_1.default.createElement("u", null, text); },
    _b[rich_text_types_1.MARKS.CODE] = function (text) { return react_1.default.createElement("code", null, text); },
    _b);
var defaultInline = function (type, node) {
    return react_1.default.createElement("span", null,
        "type: ",
        type,
        " id: ",
        node.data.target.sys.id);
};
/**
 * Contentful Rich Text `document` to a react component.
 */
function documentToReactComponent(richTextDocument, options) {
    if (options === void 0) { options = {}; }
    NODE_KEY_I = 0;
    return nodeListToReactComponent(richTextDocument.content, {
        renderNode: __assign({}, defaultNodeRenderers, options.renderNode),
        renderMark: __assign({}, defaultMarkRenderers, options.renderMark),
    });
}
exports.documentToReactComponent = documentToReactComponent;
function nodeListToReactComponent(nodes, _a) {
    var renderNode = _a.renderNode, renderMark = _a.renderMark;
    return nodes.map(function (node) { return nodeToReactComponent(node, { renderNode: renderNode, renderMark: renderMark }); });
}
function nodeToReactComponent(node, _a) {
    var renderNode = _a.renderNode, renderMark = _a.renderMark;
    if (rich_text_types_1.helpers.isText(node)) {
        if (node.marks.length > 0) {
            return node.marks.reduce(function (value, mark) {
                if (!renderMark[mark.type]) {
                    return value;
                }
                return __assign({}, renderMark[mark.type](value), { key: NODE_KEY_I++ });
            }, node.value);
        }
        return node.value;
    }
    else {
        var nextNode = function (nodes) { return nodeListToReactComponent(nodes, { renderMark: renderMark, renderNode: renderNode }); };
        if (!node.nodeType || !renderNode[node.nodeType]) {
            // TODO: Figure what to return when passed an unrecognized node.
            return null;
        }
        return __assign({}, renderNode[node.nodeType](node, nextNode), { key: NODE_KEY_I++ });
    }
}
//# sourceMappingURL=index.js.map